@@ -13,16 +13,18 @@
  * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
+#ifndef _EXUDE_H_
+#define _EXUDE_H_
 
+#include <stdint.h>
 #include <stdlib.h>
 #include <stdarg.h>
-#include <sys/tree.h>
 
 /* versioning */
 #define EXUDE_STRINGIFY(x)	#x
 #define EXUDE_STR(x)		EXUDE_STRINGIFY(x)
 #define EXUDE_VERSION_MAJOR	0
-#define EXUDE_VERSION_MINOR	6
+#define EXUDE_VERSION_MINOR	7
 #define EXUDE_VERSION_PATCH	0
 #define EXUDE_VERSION		EXUDE_STR(EXUDE_VERSION_MAJOR) "." \
 				EXUDE_STR(EXUDE_VERSION_MINOR) "." \
@@ -33,10 +35,9 @@ void		 exude_version(int *major, int *minor, int *patch);
 #define	EXUDE_DBG_ALWAYS	(~(0Ull))
 void		 exude_enable(uint64_t);
 void		 exude_disable(void);
+void		 exude_enable_threads(void);
+void		 exude_cleanup(void);
 
-#define E_MEM_DEBUG
-
-#ifdef E_MEM_DEBUG
 void	e_check_memory(void);
 void	*e_malloc_debug(size_t, const char *, const char *, int);
 void	*e_calloc_debug(size_t, size_t, const char *, const char *, int);
@@ -59,30 +60,4 @@ void	*e_realloc_debug(void *, size_t, const char *, const char *, int);
 				    __LINE__, b, c)
 #define e_realloc(a,b)	e_realloc_debug(a, b, __FILE__, __FUNCTION__, __LINE__)
 
-struct e_mem_debug {
-	void		*emd_address;
-	size_t		emd_size;
-	const char	*emd_file;
-	const char	*emd_func;
-	int		emd_line;
-	RB_ENTRY(e_mem_debug)	emd_entry;	/* r/b on address */
-};
-RB_HEAD(e_mem_debug_tree, e_mem_debug);
-
-#else /* E_MEM_DEBUG */
-#define e_check_memory()
-void	*e_malloc_internal(size_t);
-void	*e_calloc_internal(size_t, size_t);
-void	e_free_internal(void **);
-char	*e_strdup_internal(const char *);
-int	e_asprintf_internal(char **, const char *, ...);
-int	e_vasprintf_internal(char **t, const char *, va_list);
-void	*e_realloc_internal(void *, size_t);
-#define e_malloc(a)	e_malloc_internal(a)
-#define e_malloc(a, b)	e_calloc_internal(a, b)
-#define e_free(a)	e_free_internal((void **)a)
-#define e_strdup(a)	e_strdup_internal(a)
-#define e_asprintf(a,b...)	e_asprintf_internal(a, b)
-#define e_vasprintf(a,b, va)	e_vasprintf_internal(a, b, va)
-#define e_realloc(a, b)	e_realloc_internal(a, b)
-#endif
+#endif /* ! _EXUDE_H_ */
